import objc
from Foundation import *
from AppKit import *
import sys
import os.path
import metadata
import annotate
		
class DRMergeController(NSObject):
	progressWindow = objc.IBOutlet()
	progressBar = objc.IBOutlet()
	progressText = objc.IBOutlet()
	
	@objc.IBAction
	def merge_(self,sender):
		panel = NSOpenPanel.openPanel()
		panel.setCanChooseDirectories_(False)
		panel.setAllowsMultipleSelection_(False)
		ret_value = panel.runModalForTypes_(('pdf',))
		if ret_value:
			self.doMerge(panel.filenames()[0])

	def showError(self, message):
		alert = NSAlert.alloc().init()
		alert.addButtonWithTitle_("OK")
		alert.setMessageText_("Merge Error")
		alert.setInformativeText_(message)
		alert.setAlertStyle_(NSWarningAlertStyle)
		alert.runModal()
		
	def showInfo(self, message):
		alert = NSAlert.alloc().init()
		alert.addButtonWithTitle_("OK")
		alert.setMessageText_("Merge Complete")
		alert.setInformativeText_(message)
		alert.setAlertStyle_(NSInformationalAlertStyle)
		alert.runModal()
		
	def progressCallback(self, n, total):
		self.progressBar.setDoubleValue_(n/float(total)*100.0)
		self.progressText.setStringValue_("%d/%d strokes merged" % (n,total))
			
	def doMerge(self, filename):
		self.filename = filename
		t = NSThread.alloc().initWithTarget_selector_object_(self,self.doActualMerge, None)
		t.start()
	
	def doActualMerge(self):
		pool = NSAutoreleasePool.alloc().init()
		from quartzannotate import QuartzPDFAnnotate
		filename = self.filename

		dir = os.path.dirname(filename)
		outfile = ".".join(filename.split(".")[:-1])+"_merged.pdf"

		mdb = metadata.MetaDB(os.path.join(dir,"metadata.db"))
		ann = QuartzPDFAnnotate(mdb)
		ann.load(filename)
		try:
			self.progressWindow.makeKeyAndOrderFront_(self)
			ann.annotateToFile(outfile, self.progressCallback)
			self.progressWindow.close()
		except annotate.NoScribblesException:
			self.showError("No scribbles for '%s'" % (filename))
			return
			
		self.showInfo("%d strokes merged to %s" % (ann.numStrokes, os.path.basename(outfile)))
		pool.release()
				
