import scribble
import os.path

class NoScribblesException(Exception):
	def __init__(self, filename):
		Exception.__init__(self)
		self.filename = filename

class PDFAnnotate:
	def __init__(self, mdb):
		self.mdb = mdb

	def load(self, fn):
		self.filename = fn
		self.loadFromPDF(fn)
		self.numStrokes = 0
		
	def annotateToFile(self, fn, progressCallback=None):
		scribbles = self.mdb.getAnnotationsForFile(os.path.basename(self.filename),"scribble")
		if not scribbles:
			raise NoScribblesException(fn)

		for scb in scribbles:
			scrib = scribble.Scribble()
			scrib.loadFromData(scb["data"])
			anchor = scb["start_anchor"]
			if "pdf:/page:" in anchor:
				pn = int(anchor.split(":")[-1])
				apage = self.startPageAnnotations(pn)
				pagew = self.getPageWidth(apage)
				pageh = self.getPageHeight(apage)
				rot = self.getPageRotation(apage)
				
				for stroke in scrib.strokes:
					self.numStrokes += 1
					if progressCallback:
						progressCallback(self.numStrokes, len(scrib.strokes))
					astroke = self.startStrokeAnnotation(stroke)
					for l in stroke.lines:
						if rot==0:
							sx = l[0][0]
							sy = pageh-l[0][1]
							ex = l[1][0]
							ey = pageh-l[1][1]
						elif rot==90:
							sy = l[0][0]
							sx = l[0][1]
							ey = l[1][0]
							ex = l[1][1]
						elif rot==180:
							sx = pagew-l[0][0]
							sy = l[0][1]
							ex = pagew-l[1][0]
							ey = l[1][1]
						else:
							raise Exception("Unknown rotation %d" % rot)
						self.drawLineAnnotation(apage, astroke, sx, sy, ex, ey)
			else:
				raise Exception("unkown anchor %s" % anchor)

		self.saveToPDF(fn)
