from Quartz import *
import objc
from annotate import PDFAnnotate

class QuartzPDFAnnotate(PDFAnnotate):
	def __init__(self, mdb):
		PDFAnnotate.__init__(self, mdb)

	def loadFromPDF(self, fn):
		url = NSURL.fileURLWithPath_(fn)
		self.pdf = PDFDocument.alloc().initWithURL_(url)

	def saveToPDF(self, fn):
		self.pdf.writeToFile_(fn)

	def startPageAnnotations(self, pagenum):
		self.page = self.pdf.pageAtIndex_(pagenum-1)
		self.bounds = self.page.boundsForBox_(kPDFDisplayBoxMediaBox)
		return self.page

	def getPageWidth(self, apage):
		return self.bounds[1][0]
	
	def getPageHeight(self, apage):
		return self.bounds[1][1]
	
	def getPageRotation(self, apage):
		self.rot = self.page.rotation()
		return self.rot

	def startStrokeAnnotation(self, stroke):
		self.border = PDFBorder.alloc().init()
		self.border.setLineWidth_(0.5 * stroke.size)
		return self.border

	def drawLineAnnotation(self, page, stroke, sx, sy, ex, ey):
		# shift around for pdf crop box
		bc = page.boundsForBox_(kPDFDisplayBoxCropBox)
		#scalex = bc[1][0]/bounds[1][0]
		#scaley = bc[1][1]/bounds[1][1]
		ofsx = bc[0][0]
		ofsy = 0 #bc[0][1] - not sure why this doesnt work
		sx += ofsx
		sy += ofsy
		ex += ofsx
		ey += ofsy
		# reorder co-ordinates for bounding box
		flipx = False
		if (sx>ex):
			t = sx
			sx = ex
			ex = t
			flipx = True
		flipy = False
		if (sy>ey):
			t = sy
			sy = ey
			ey = t
			flipy = True
		# create annotation with bounding box
		pad = 2
		bounds = NSMakeRect(sx-pad, sy-pad, ex-sx+pad*2, ey-sy+pad*2)
		pdfline = PDFAnnotationLine.alloc().initWithBounds_(bounds)
		# set line inside bounding box
		px1 = pad
		py1 = pad
		px2 = ex-sx+pad
		py2 = ey-sy+pad
		if flipx:
			px1 = ex-sx+pad
			px2 = pad
		if flipy:
			py1 = ey-sy+pad
			py2 = pad
		pdfline.setStartPoint_((px1,py1))
		pdfline.setEndPoint_((px2, py2))
		pdfline.setBorder_(stroke)
		# add line to pdf
		page.addAnnotation_(pdfline)

